# Release checklist

- [ ] Upgrade Docs prior to Release

    - [ ] Change log
    - [ ] New features documented
    - [ ] Update the contributor list - thank you page

- [ ] Release software

    - [ ] Make sure 0 issues in milestone
    - [ ] Follow release process steps
    - [ ] Send builds to PyPI (Warehouse) and Conda Forge

- [ ] Blog post and/or release note

- [ ] Notify users of release

    - [ ] Tweet

- [ ] Increment the version number for the next release

- [ ] Update roadmap
